@@ -1,27 +1,70 @@
 import sqlite3
 import os
-#from importlib import resources
+import importlib
 
 
+
+dbMap = {
+    "dbiu.bahn":1,
+    "dbiu.bayern":2,
+    "dbiu.bundestag": 3,
+    "dbiu.bundestag_einfach": 4,
+    "dbiu.film_fernsehen": 5,
+    "dbiu.haushaltsausstattung": 6,
+    "dbiu.straftaten": 7,
+    "dbiu.straftaten_einfach": 8,
+    "dbiu.kunstsammlung": 9,
+    "dbiu.ladepunkte": 10,
+    "dbiu.laenderspiele": 11,
+    "dbiu.lebensmittel": 12,
+    "dbiu.schulstatistik": 13,
+    "dbiu.studierende": 14,
+    "dbiu.unfallstatistik": 15,
+    "dbiu.videospiele_einfach": 16,
+    "dbiu.videospiele": 17,
+    "dbiu.wetterdaten": 18
+}
+
 __db=""
 
-def setDBName(path: str):
+def setDBName(database):
     global __db
-    print("Setting DB to: " + path)
-    __db = path
-    #with resources.path('sql_testing_tools', path) as db_path:
-    #    __db = str(db_path)
-    #    print(__db)
 
+    if isinstance(database, str) and database.startswith("dbiu."):
+        dbVersion = dbMap.get(database)
+    elif isinstance(database, int):
+        dbVersion = database
+        database = "dbiu."+str(database)
+    elif isinstance(database, str):
+        dbVersion = None
+    else:
+        raise Exception("Invalid database selected")
+        
+    if(dbVersion is not None):
+        os.system('pip install dbiu_databases=='+str(dbVersion))
+        try:
+            import dbiu_databases
+        except ImportError:
+            raise Exception("Invalid database selected")
+    print("Setting DB to: " + database)
+    __db = database
 
-#setDBName("databases/bayern.db")
-
+    
 def run(sql: str):
-    con = sqlite3.connect(__db)
-    cur = con.cursor()
-    cur.execute(sql)
-    con.commit()
-    return cur
+    global __db
+
+    if __db.startswith("dbiu.") and not __db.endswith(".db"):
+        with importlib.resources.path('dbiu_databases', "base.db") as db_path:
+            return __run(sql, db_path)
+    else:
+        return __run(sql, __db)
+
+def __run(sql: str, db: str):
+    with sqlite3.connect(db) as con:
+        cur = con.cursor()
+        cur.execute(sql)
+        con.commit()
+        return cur
 
 def runFromFile(path: str):
     sql = getSQLFromFile(path)
